[MPlayer-dev-eng] [PATCH] hwsync

David Holm dholm at iname.com
Wed Jan 16 21:09:43 CET 2002


Hope I got my hexes right this time, 0x10? And this time I modified
vo_mpegpes as well.

On Wed, 2002-01-16 at 20:52, Arpi wrote:
> Hi,
> 
> > Hmm, the tech doc said hwsync was 0x100. The obvious predecessor is 0xf
> 
> 0xf ????
> where, what, when?
> 
> 0xf can't be a flag, as it's 8|4|2|1, so 4 flags ored...
> 
> > though, this patch modifies mplayer.c and tech-eng doc to use 0xf. I
> > forgot to fix vo_dvb though (next vo_dxr3 commit will be updated, but
> > I'm close to fixing hardware sync right now so I didn't want to send any
> > experimental code)...
> > 
> > //David
> > 
> > 
> > Index: mplayer.c
> > ===================================================================
> > RCS file: /cvsroot/mplayer/main/mplayer.c,v
> > retrieving revision 1.368
> > diff -u -r1.368 mplayer.c
> > --- mplayer.c	15 Jan 2002 17:03:18 -0000	1.368
> > +++ mplayer.c	16 Jan 2002 19:35:01 -0000
> > @@ -1631,7 +1631,7 @@
> >        }
> >  #endif
> >  
> > -if(!(vo_flags&256)){ // flag 256 means: libvo driver does its timing (dvb card)
> > +if(!(vo_flags&0xf)){ // flag 0xf means: libvo driver does its timing (dvb/dxr3 card)
> >  
> >  #ifdef HAVE_RTC
> >      if(rtc_fd>=0){
> > Index: DOCS/tech/tech-eng.txt
> > ===================================================================
> > RCS file: /cvsroot/mplayer/main/DOCS/tech/tech-eng.txt,v
> > retrieving revision 1.18
> > diff -u -r1.18 tech-eng.txt
> > --- DOCS/tech/tech-eng.txt	15 Jan 2002 00:24:57 -0000	1.18
> > +++ DOCS/tech/tech-eng.txt	16 Jan 2002 19:35:02 -0000
> > @@ -191,8 +191,8 @@
> >  			0x1  -  supported (by hardware or conversion)
> >  			0x2  -  supported (by hardware, without conversion)
> >  			0x4  -  sub/osd supported (has draw_alpha)
> > -			0x8  -  hardware handles subpics
> > -			0x100  -  driver/hardware handles timing (blocking)
> > +			0x8  -  hardware handles subpics (see libvo/vo_dxr3.c)
> > +			0xf  -  driver/hardware handles timing (blocking)
> >  
> >     IMPORTANT: it's mandatorial that every vo driver support the YV12 format,
> >  	 and one (or both) of BGR15 and BGR24, with conversion, if needed.
> > 
> > 
> > _______________________________________________
> > MPlayer-dev-eng mailing list
> > MPlayer-dev-eng at mplayerhq.hu
> > http://mplayerhq.hu/mailman/listinfo/mplayer-dev-eng
> > 
> > 
> 
> 
> A'rpi / Astral & ESP-team
> 
> --
> mailto:arpi at thot.banki.hu
> http://esp-team.scene.hu
> _______________________________________________
> MPlayer-dev-eng mailing list
> MPlayer-dev-eng at mplayerhq.hu
> http://mplayerhq.hu/mailman/listinfo/mplayer-dev-eng

-------------- next part --------------
Index: DOCS/tech/tech-eng.txt
===================================================================
RCS file: /cvsroot/mplayer/main/DOCS/tech/tech-eng.txt,v
retrieving revision 1.18
diff -u -r1.18 tech-eng.txt
--- DOCS/tech/tech-eng.txt	15 Jan 2002 00:24:57 -0000	1.18
+++ DOCS/tech/tech-eng.txt	16 Jan 2002 20:17:21 -0000
@@ -191,8 +191,8 @@
 			0x1  -  supported (by hardware or conversion)
 			0x2  -  supported (by hardware, without conversion)
 			0x4  -  sub/osd supported (has draw_alpha)
-			0x8  -  hardware handles subpics
-			0x100  -  driver/hardware handles timing (blocking)
+			0x8  -  hardware handles subpics (see libvo/vo_dxr3.c)
+			0x10 -  driver/hardware handles timing (blocking)
 
    IMPORTANT: it's mandatorial that every vo driver support the YV12 format,
 	 and one (or both) of BGR15 and BGR24, with conversion, if needed.
Index: libvo/vo_mpegpes.c
===================================================================
RCS file: /cvsroot/mplayer/main/libvo/vo_mpegpes.c,v
retrieving revision 1.12
diff -u -r1.12 vo_mpegpes.c
--- libvo/vo_mpegpes.c	5 Nov 2001 21:49:20 -0000	1.12
+++ libvo/vo_mpegpes.c	16 Jan 2002 20:17:21 -0000
@@ -464,9 +464,9 @@
 static uint32_t
 query_format(uint32_t format)
 {
-    if(format==IMGFMT_MPEGPES) return 1|256;
+    if(format==IMGFMT_MPEGPES) return 0x1|0x10;
 #ifdef USE_LIBAVCODEC
-    if(format==IMGFMT_YV12) return 1|256;
+    if(format==IMGFMT_YV12) return 0x1|0x10;
 #endif
     return 0;
 }


More information about the MPlayer-dev-eng mailing list
Index: mplayer.c
===================================================================
RCS file: /cvsroot/mplayer/main/mplayer.c,v
retrieving revision 1.368
diff -u -r1.368 mplayer.c
--- mplayer.c	15 Jan 2002 17:03:18 -0000	1.368
+++ mplayer.c	16 Jan 2002 20:17:21 -0000
@@ -1631,7 +1631,7 @@
       }
 #endif
 
-if(!(vo_flags&256)){ // flag 256 means: libvo driver does its timing (dvb card)
+if(!(vo_flags&0x10)){ // flag 0x10 means: libvo driver does its timing (dvb/dxr3 card)
 
 #ifdef HAVE_RTC
     if(rtc_fd>=0){